@@ -26,7 +26,7 @@
 #include "util.h"
 
 typedef struct EditorObject {
-	PyObject_HEAD
+	PyObject_VAR_HEAD
 	const svn_delta_editor_t *editor;
 	void *baton;
 	apr_pool_t *pool;
@@ -120,8 +120,12 @@ static PyObject *txdelta_call(PyObject *self, PyObject *args, PyObject *kwargs)
 	if (py_new_data == Py_None) {
 		window.new_data = NULL;
 	} else {
-		new_data.data = PyString_AsString(py_new_data);
-		new_data.len = PyString_Size(py_new_data);
+		if (!PyBytes_Check(py_new_data)) {
+			PyErr_SetString(PyExc_TypeError, "delta data should be bytes");
+			return NULL;
+		}
+		new_data.data = PyBytes_AsString(py_new_data);
+		new_data.len = PyBytes_Size(py_new_data);
 		window.new_data = &new_data;
 	}
 
@@ -164,7 +168,7 @@ static void py_txdelta_window_handler_dealloc(PyObject *self)
 }
 
 PyTypeObject TxDeltaWindowHandler_Type = {
-	PyObject_HEAD_INIT(NULL) 0,
+	PyVarObject_HEAD_INIT(NULL, 0)
 	"_ra.TxDeltaWindowHandler", /*	const char *tp_name;  For printing, in format "<module>.<name>" */
 	sizeof(TxDeltaWindowHandlerObject), 
 	0,/*	Py_ssize_t tp_basicsize, tp_itemsize;  For allocation */
@@ -302,7 +306,7 @@ static PyMethodDef py_file_editor_methods[] = {
 };
 
 PyTypeObject FileEditor_Type = { 
-	PyObject_HEAD_INIT(NULL) 0, 
+	PyVarObject_HEAD_INIT(NULL, 0)
 	"_ra.FileEditor", /*	const char *tp_name;  For printing, in format "<module>.<name>" */
 	sizeof(EditorObject), 
 	0,/*	Py_ssize_t tp_basicsize, tp_itemsize;  For allocation */
@@ -364,10 +368,11 @@ PyTypeObject FileEditor_Type = {
 static PyObject *py_dir_editor_delete_entry(PyObject *self, PyObject *args)
 {
 	EditorObject *editor = (EditorObject *)self;
-	char *path; 
+	const char *path;
+	PyObject *py_path;
 	svn_revnum_t revision = -1;
 
-	if (!PyArg_ParseTuple(args, "s|l", &path, &revision))
+	if (!PyArg_ParseTuple(args, "O|l", &py_path, &revision))
 		return NULL;
 
 	if (editor->done) {
@@ -380,22 +385,27 @@ static PyObject *py_dir_editor_delete_entry(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
-	RUN_SVN(editor->editor->delete_entry(svn_path_canonicalize(path, editor->pool),
-										 revision, editor->baton, editor->pool));
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
+	RUN_SVN(editor->editor->delete_entry(path, revision, editor->baton, editor->pool));
 
 	Py_RETURN_NONE;
 }
 
 static PyObject *py_dir_editor_add_directory(PyObject *self, PyObject *args)
 {
-	char *path;
-	char *copyfrom_path=NULL; 
-	svn_revnum_t copyfrom_rev=-1;
-   	void *child_baton;
+	PyObject *py_path;
+	const char *path;
+	char *copyfrom_path = NULL;
+	svn_revnum_t copyfrom_rev = -1;
+	void *child_baton;
 	EditorObject *editor = (EditorObject *)self;
 	apr_pool_t *subpool;
 
-	if (!PyArg_ParseTuple(args, "s|zl", &path, &copyfrom_path, &copyfrom_rev))
+	if (!PyArg_ParseTuple(args, "O|zl", &py_path, &copyfrom_path, &copyfrom_rev))
 		return NULL;
 
 	if (editor->done) {
@@ -408,9 +418,14 @@ static PyObject *py_dir_editor_add_directory(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
 	RUN_SVN(editor->editor->add_directory(
-		svn_path_canonicalize(path, editor->pool), editor->baton,
-		copyfrom_path == NULL?NULL:svn_path_canonicalize(copyfrom_path, editor->pool), 
+		path, editor->baton,
+		copyfrom_path == NULL?NULL:svn_uri_canonicalize(copyfrom_path, editor->pool),
 		copyfrom_rev, editor->pool, &child_baton));
 
 	subpool = Pool(editor->pool);
@@ -423,13 +438,14 @@ static PyObject *py_dir_editor_add_directory(PyObject *self, PyObject *args)
 
 static PyObject *py_dir_editor_open_directory(PyObject *self, PyObject *args)
 {
-	char *path;
+	const char *path;
+	PyObject *py_path;
 	EditorObject *editor = (EditorObject *)self;
 	svn_revnum_t base_revision=-1;
 	void *child_baton;
 	apr_pool_t *subpool;
 
-	if (!PyArg_ParseTuple(args, "s|l", &path, &base_revision))
+	if (!PyArg_ParseTuple(args, "O|l", &py_path, &base_revision))
 		return NULL;
 
 	if (editor->done) {
@@ -442,15 +458,19 @@ static PyObject *py_dir_editor_open_directory(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
 	RUN_SVN(editor->editor->open_directory(
-		svn_path_canonicalize(path, editor->pool), editor->baton,
-					base_revision, editor->pool, &child_baton));
+		path, editor->baton, base_revision, editor->pool, &child_baton));
 
 	subpool = Pool(NULL);
 	if (subpool == NULL)
 		return NULL;
 
-	return new_editor_object(editor, editor->editor, child_baton, subpool, 
+	return new_editor_object(editor, editor->editor, child_baton, subpool,
 							 &DirectoryEditor_Type, NULL, NULL, NULL);
 }
 
@@ -476,7 +496,7 @@ static PyObject *py_dir_editor_change_prop(PyObject *self, PyObject *args)
 
 	c_value.len = vallen;
 
-	RUN_SVN(editor->editor->change_dir_prop(editor->baton, name, 
+	RUN_SVN(editor->editor->change_dir_prop(editor->baton, name,
 					(c_value.data == NULL)?NULL:&c_value, editor->pool));
 
 	Py_RETURN_NONE;
@@ -512,10 +532,11 @@ static PyObject *py_dir_editor_close(PyObject *self)
 
 static PyObject *py_dir_editor_absent_directory(PyObject *self, PyObject *args)
 {
-	char *path;
+	const char *path;
+	PyObject *py_path;
 	EditorObject *editor = (EditorObject *)self;
 
-	if (!PyArg_ParseTuple(args, "s", &path))
+	if (!PyArg_ParseTuple(args, "O", &py_path))
 		return NULL;
 
 	if (editor->done) {
@@ -528,21 +549,28 @@ static PyObject *py_dir_editor_absent_directory(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
 	RUN_SVN(editor->editor->absent_directory(
-		svn_path_canonicalize(path, editor->pool), editor->baton, editor->pool));
+		path, editor->baton, editor->pool));
 
 	Py_RETURN_NONE;
 }
 
 static PyObject *py_dir_editor_add_file(PyObject *self, PyObject *args)
 {
-	char *path, *copy_path=NULL;
+	const char *path;
+	char *copy_path=NULL;
+	PyObject *py_path;
 	svn_revnum_t copy_rev=-1;
 	void *file_baton = NULL;
 	EditorObject *editor = (EditorObject *)self;
 	apr_pool_t *subpool;
 
-	if (!PyArg_ParseTuple(args, "s|zl", &path, &copy_path, &copy_rev))
+	if (!PyArg_ParseTuple(args, "O|zl", &py_path, &copy_path, &copy_rev))
 		return NULL;
 
 	if (editor->done) {
@@ -555,9 +583,13 @@ static PyObject *py_dir_editor_add_file(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
-	RUN_SVN(editor->editor->add_file(svn_path_canonicalize(path, editor->pool),
-		editor->baton, 
-		copy_path == NULL?NULL:svn_path_canonicalize(copy_path, editor->pool),
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
+	RUN_SVN(editor->editor->add_file(path, editor->baton,
+		copy_path == NULL?NULL:svn_uri_canonicalize(copy_path, editor->pool),
 		copy_rev, editor->pool, &file_baton));
 
 	subpool = Pool(NULL);
@@ -570,13 +602,14 @@ static PyObject *py_dir_editor_add_file(PyObject *self, PyObject *args)
 
 static PyObject *py_dir_editor_open_file(PyObject *self, PyObject *args)
 {
-	char *path;
+	const char *path;
+	PyObject *py_path;
 	svn_revnum_t base_revision=-1;
 	void *file_baton;
 	EditorObject *editor = (EditorObject *)self;
 	apr_pool_t *subpool;
 
-	if (!PyArg_ParseTuple(args, "s|l", &path, &base_revision))
+	if (!PyArg_ParseTuple(args, "O|l", &py_path, &base_revision))
 		return NULL;
 
 	if (editor->done) {
@@ -589,8 +622,12 @@ static PyObject *py_dir_editor_open_file(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
-	RUN_SVN(editor->editor->open_file(svn_path_canonicalize(path, editor->pool),
-									  editor->baton, base_revision, 
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
+	RUN_SVN(editor->editor->open_file(path, editor->baton, base_revision,
 									  editor->pool, &file_baton));
 
 	subpool = Pool(NULL);
@@ -603,10 +640,11 @@ static PyObject *py_dir_editor_open_file(PyObject *self, PyObject *args)
 
 static PyObject *py_dir_editor_absent_file(PyObject *self, PyObject *args)
 {
-	char *path;
+	const char *path;
+	PyObject *py_path;
 	EditorObject *editor = (EditorObject *)self;
 
-	if (!PyArg_ParseTuple(args, "s", &path))
+	if (!PyArg_ParseTuple(args, "O", &py_path))
 		return NULL;
 
 	if (editor->done) {
@@ -619,8 +657,13 @@ static PyObject *py_dir_editor_absent_file(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+	path = py_object_to_svn_relpath(py_path, editor->pool);
+	if (path == NULL) {
+		return NULL;
+	}
+
 	RUN_SVN(editor->editor->absent_file(
-		svn_path_canonicalize(path, editor->pool), editor->baton, editor->pool));
+		path, editor->baton, editor->pool));
 
 	Py_RETURN_NONE;
 }
@@ -676,65 +719,64 @@ static PyMethodDef py_dir_editor_methods[] = {
 	{ NULL, }
 };
 
-PyTypeObject DirectoryEditor_Type = { 
-	PyObject_HEAD_INIT(NULL) 0,
+PyTypeObject DirectoryEditor_Type = {
+	PyVarObject_HEAD_INIT(NULL, 0)
 	"_ra.DirEditor", /*	const char *tp_name;  For printing, in format "<module>.<name>" */
-	sizeof(EditorObject), 
+	sizeof(EditorObject),
 	0,/*	Py_ssize_t tp_basicsize, tp_itemsize;  For allocation */
-	
+
 	/* Methods to implement standard operations */
-	
+
 	py_editor_dealloc, /* destructor tp_dealloc;  */
 	NULL, /*	printfunc tp_print;	*/
 	NULL, /*	getattrfunc tp_getattr;	*/
 	NULL, /*	setattrfunc tp_setattr;	*/
 	NULL, /*	cmpfunc tp_compare;	*/
 	NULL, /*	reprfunc tp_repr;	*/
-	
+
 	/* Method suites for standard classes */
-	
+
 	NULL, /*	PyNumberMethods *tp_as_number;	*/
 	NULL, /*	PySequenceMethods *tp_as_sequence;	*/
 	NULL, /*	PyMappingMethods *tp_as_mapping;	*/
-	
+
 	/* More standard operations (here for binary compatibility) */
-	
+
 	NULL, /*	hashfunc tp_hash;	*/
 	NULL, /*	ternaryfunc tp_call;	*/
 	NULL, /*	reprfunc tp_str;	*/
 	NULL, /*	getattrofunc tp_getattro;	*/
 	NULL, /*	setattrofunc tp_setattro;	*/
-	
+
 	/* Functions to access object as input/output buffer */
 	NULL, /*	PyBufferProcs *tp_as_buffer;	*/
-	
+
 	/* Flags to define presence of optional/expanded features */
 	0, /*	long tp_flags;	*/
-	
+
 	NULL, /*	const char *tp_doc;  Documentation string */
-	
+
 	/* Assigned meaning in release 2.0 */
 	/* call function for all accessible objects */
 	NULL, /*	traverseproc tp_traverse;	*/
-	
+
 	/* delete references to contained objects */
 	NULL, /*	inquiry tp_clear;	*/
-	
+
 	/* Assigned meaning in release 2.1 */
 	/* rich comparisons */
 	NULL, /*	richcmpfunc tp_richcompare;	*/
-	
+
 	/* weak reference enabler */
 	0, /*	Py_ssize_t tp_weaklistoffset;	*/
-	
+
 	/* Added in release 2.2 */
 	/* Iterators */
 	NULL, /*	getiterfunc tp_iter;	*/
 	NULL, /*	iternextfunc tp_iternext;	*/
-	
+
 	/* Attribute descriptor and subclassing stuff */
 	py_dir_editor_methods, /*	struct PyMethodDef *tp_methods;	*/
-	
 };
 
 static PyObject *py_editor_set_target_revision(PyObject *self, PyObject *args)
@@ -880,7 +922,7 @@ static PyMethodDef py_editor_methods[] = {
 };
 
 PyTypeObject Editor_Type = { 
-	PyObject_HEAD_INIT(NULL) 0,
+	PyVarObject_HEAD_INIT(NULL, 0)
 	"_ra.Editor", /*	const char *tp_name;  For printing, in format "<module>.<name>" */
 	sizeof(EditorObject), 
 	0,/*	Py_ssize_t tp_basicsize, tp_itemsize;  For allocation */
@@ -1106,8 +1148,8 @@ svn_error_t *py_txdelta_window_handler(svn_txdelta_window_t *window, void *baton
 			}
 		}
 		if (window->new_data != NULL && window->new_data->data != NULL) {
-			py_new_data = PyString_FromStringAndSize(window->new_data->data,
-													 window->new_data->len);
+			py_new_data = PyBytes_FromStringAndSize(window->new_data->data,
+													window->new_data->len);
 		} else {
 			py_new_data = Py_None;
 			Py_INCREF(py_new_data);
