@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2007 Jelmer Vernooij <jelmer@jelmer.uk>
- 
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation; either version 2.1 of the License, or
@@ -17,9 +17,10 @@
 
 from datetime import datetime, timedelta
 import os
-from StringIO import StringIO
+from io import BytesIO
 import shutil
 import tempfile
+from unittest import SkipTest
 
 from subvertpy import (
     SubversionException,
@@ -30,7 +31,6 @@ from subvertpy import (
     )
 from subvertpy.tests import (
     SubversionTestCase,
-    SkipTest,
     TestCase,
     )
 
@@ -70,17 +70,18 @@ class TestClient(SubversionTestCase):
         self.client.commit(["dc"])
         r = ra.RemoteAccess(self.repos_url)
         revprops = r.rev_proplist(1)
-        self.assertEqual("Amessage", revprops["svn:log"])
+        self.assertEqual(b"Amessage", revprops["svn:log"])
 
     def test_commit_start(self):
         self.build_tree({"dc/foo": None})
-        self.client = client.Client(auth=ra.Auth([ra.get_username_provider()]),
-                log_msg_func=lambda c: "Bmessage")
+        self.client = client.Client(
+            auth=ra.Auth([ra.get_username_provider()]),
+            log_msg_func=lambda c: "Bmessage")
         self.client.add("dc/foo")
         self.client.commit(["dc"])
         r = ra.RemoteAccess(self.repos_url)
         revprops = r.rev_proplist(1)
-        self.assertEqual("Bmessage", revprops["svn:log"])
+        self.assertEqual(b"Bmessage", revprops["svn:log"])
 
     def test_mkdir(self):
         self.client.mkdir(["dc/foo"])
@@ -88,14 +89,22 @@ class TestClient(SubversionTestCase):
         self.client.mkdir("dc/bla", revprops={"svn:log": "foo"})
 
     def test_export(self):
-        self.build_tree({"dc/foo": "bla"})
+        self.build_tree({"dc/foo": b"bla"})
         self.client.add("dc/foo")
         self.client.commit(["dc"])
         self.client.export(self.repos_url, "de")
         self.assertEqual(["foo"], os.listdir("de"))
 
+    def test_export_new_option(self):
+        self.build_tree({"dc/foo": b"bla"})
+        self.client.add("dc/foo")
+        self.client.commit(["dc"])
+        self.client.export(self.repos_url, "de", ignore_externals=True,
+                           ignore_keywords=True)
+        self.assertEqual(["foo"], os.listdir("de"))
+
     def test_add_recursive(self):
-        self.build_tree({"dc/trunk/foo": 'bla', "dc/trunk": None})
+        self.build_tree({"dc/trunk/foo": b'bla', "dc/trunk": None})
         self.client.add("dc/trunk")
         if getattr(wc, "WorkingCopy", None) is None:
             raise SkipTest(
@@ -121,32 +130,33 @@ class TestClient(SubversionTestCase):
             config = client.get_config(svn_cfg_dir)
             self.assertIsInstance(config, client.Config)
             ignores = config.get_default_ignores()
-            self.assertTrue(base_dir_basename in ignores)
+            self.assertTrue(
+                base_dir_basename.encode('utf-8') in ignores,
+                "no %r in %r" % (base_dir_basename, ignores))
         finally:
             shutil.rmtree(base_dir)
 
     def test_diff(self):
-        r = ra.RemoteAccess(self.repos_url,
-                auth=ra.Auth([ra.get_username_provider()]))
-        dc = self.get_commit_editor(self.repos_url) 
+        dc = self.get_commit_editor(self.repos_url)
         f = dc.add_file("foo")
-        f.modify("foo1")
+        f.modify(b"foo1")
         dc.close()
 
-        dc = self.get_commit_editor(self.repos_url) 
+        dc = self.get_commit_editor(self.repos_url)
         f = dc.open_file("foo")
-        f.modify("foo2")
+        f.modify(b"foo2")
         dc.close()
 
         if client.api_version() < (1, 5):
-            self.assertRaises(NotImplementedError, self.client.diff, 1, 2,
+            self.assertRaises(
+                NotImplementedError, self.client.diff, 1, 2,
                 self.repos_url, self.repos_url)
-            return # Skip test
+            return  # Skip test
 
         (outf, errf) = self.client.diff(1, 2, self.repos_url, self.repos_url)
         self.addCleanup(outf.close)
         self.addCleanup(errf.close)
-        self.assertEqual("""Index: foo
+        self.assertEqual(b"""Index: foo
 ===================================================================
 --- foo\t(revision 1)
 +++ foo\t(revision 2)
@@ -155,25 +165,25 @@ class TestClient(SubversionTestCase):
 \\ No newline at end of file
 +foo2
 \\ No newline at end of file
-""", outf.read())
-        self.assertEqual("", errf.read())
+""".splitlines(), outf.read().splitlines())
+        self.assertEqual(b"", errf.read())
 
     def assertCatEquals(self, value, revision=None):
-        io = StringIO()
+        io = BytesIO()
         self.client.cat("dc/foo", io, revision)
         self.assertEqual(value, io.getvalue())
 
     def test_cat(self):
-        self.build_tree({"dc/foo": "bla"})
+        self.build_tree({"dc/foo": b"bla"})
         self.client.add("dc/foo")
         self.client.log_msg_func = lambda c: "Commit"
         self.client.commit(["dc"])
-        self.assertCatEquals("bla")
-        self.build_tree({"dc/foo": "blabla"})
+        self.assertCatEquals(b"bla")
+        self.build_tree({"dc/foo": b"blabla"})
         self.client.commit(["dc"])
-        self.assertCatEquals("blabla")
-        self.assertCatEquals("bla", revision=1)
-        self.assertCatEquals("blabla", revision=2)
+        self.assertCatEquals(b"blabla")
+        self.assertCatEquals(b"bla", revision=1)
+        self.assertCatEquals(b"blabla", revision=2)
 
     def assertLogEntryChangedPathsEquals(self, expected, entry):
         changed_paths = entry["changed_paths"]
@@ -184,14 +194,17 @@ class TestClient(SubversionTestCase):
         self.assertEqual(expected, entry["revprops"]["svn:log"])
 
     def assertLogEntryDateAlmostEquals(self, expected, entry, delta):
-        actual = datetime.strptime(entry["revprops"]["svn:date"], "%Y-%m-%dT%H:%M:%S.%fZ")
+        actual = datetime.strptime(
+            entry["revprops"]["svn:date"].decode('utf-8'),
+            "%Y-%m-%dT%H:%M:%S.%fZ")
         self.assertTrue((actual - expected) < delta)
 
     def test_log(self):
         log_entries = []
-        commit_msg_1 = "Commit"
-        commit_msg_2 = "Commit 2"
+        commit_msg_1 = b"Commit"
+        commit_msg_2 = b"Commit 2"
         delta = timedelta(hours=1)
+
         def cb(changed_paths, revision, revprops, has_children=False):
             log_entries.append({
                 'changed_paths': changed_paths,
@@ -199,7 +212,7 @@ class TestClient(SubversionTestCase):
                 'revprops': revprops,
                 'has_children': has_children,
             })
-        self.build_tree({"dc/foo": "bla"})
+        self.build_tree({"dc/foo": b"bla"})
         self.client.add("dc/foo")
         self.client.log_msg_func = lambda c: commit_msg_1
         self.client.commit(["dc"])
@@ -211,8 +224,8 @@ class TestClient(SubversionTestCase):
         self.assertLogEntryMessageEquals(commit_msg_1, log_entries[0])
         self.assertLogEntryDateAlmostEquals(commit_1_dt, log_entries[0], delta)
         self.build_tree({
-            "dc/foo": "blabla",
-            "dc/bar": "blablabla",
+            "dc/foo": b"blabla",
+            "dc/bar": b"blablabla",
         })
         self.client.add("dc/bar")
         self.client.log_msg_func = lambda c: commit_msg_2
@@ -230,7 +243,8 @@ class TestClient(SubversionTestCase):
         self.assertLogEntryMessageEquals(commit_msg_1, log_entries[1])
         self.assertLogEntryDateAlmostEquals(commit_1_dt, log_entries[1], delta)
         log_entries = []
-        self.client.log(cb, "dc/foo", start_rev=2, end_rev=2, discover_changed_paths=True)
+        self.client.log(cb, "dc/foo", start_rev=2, end_rev=2,
+                        discover_changed_paths=True)
         self.assertEqual(1, len(log_entries))
         self.assertLogEntryChangedPathsEquals(["/foo", "/bar"], log_entries[0])
         self.assertEqual(2, log_entries[0]["revision"])
@@ -238,19 +252,19 @@ class TestClient(SubversionTestCase):
         self.assertLogEntryDateAlmostEquals(commit_2_dt, log_entries[0], delta)
 
     def test_info(self):
-        self.build_tree({"dc/foo": "bla"})
+        self.build_tree({"dc/foo": b"bla"})
         self.client.add("dc/foo")
         self.client.log_msg_func = lambda c: "Commit"
         self.client.commit(["dc"])
         info = self.client.info("dc/foo")
-        self.assertEqual(["foo"], info.keys())
+        self.assertEqual(["foo"], list(info.keys()))
         self.assertEqual(1, info["foo"].revision)
-        self.assertEqual(3L, info["foo"].size)
-        self.build_tree({"dc/bar": "blablabla"})
+        self.assertEqual(3, info["foo"].size)
+        self.build_tree({"dc/bar": b"blablabla"})
         self.client.add(os.path.abspath("dc/bar"))
 
     def test_info_nonexistant(self):
-        self.build_tree({"dc/foo": "bla"})
+        self.build_tree({"dc/foo": b"bla"})
         self.client.add("dc/foo")
         self.client.log_msg_func = lambda c: "Commit"
         self.client.commit(["dc"])
