@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2007 Jelmer Vernooij <jelmer@jelmer.uk>
- 
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation; either version 2.1 of the License, or
@@ -15,7 +15,7 @@
 
 """Tests for subvertpy.delta."""
 
-from cStringIO import StringIO
+from io import BytesIO
 
 from subvertpy.delta import (
     decode_length,
@@ -28,6 +28,7 @@ from subvertpy.delta import (
     )
 from subvertpy.tests import TestCase
 
+
 class DeltaTests(TestCase):
 
     def setUp(self):
@@ -38,28 +39,28 @@ class DeltaTests(TestCase):
         self.windows.append(window)
 
     def test_send_stream(self):
-        stream = StringIO("foo")
+        stream = BytesIO(b"foo")
         send_stream(stream, self.storing_window_handler)
-        self.assertEqual([(0, 0, 3, 0, [(2, 0, 3)], 'foo'), None], 
-                          self.windows)
-    
+        self.assertEqual([(0, 0, 3, 0, [(2, 0, 3)], b'foo'), None],
+                         self.windows)
+
     def test_apply_delta(self):
-        stream = StringIO()
-        source = "(source)"
+        stream = BytesIO()
+        source = b"(source)"
         handler = apply_txdelta_handler(source, stream)
-        
-        new = "(new)"
+
+        new = b"(new)"
         ops = (  # (action, offset, length)
             (TXDELTA_NEW, 0, len(new)),
             (TXDELTA_SOURCE, 0, len(source)),
-            (TXDELTA_TARGET, len(new), len("(s")),  # Copy "(s"
-            (TXDELTA_TARGET, len("(n"), len("ew)")),  # Copy "ew)"
-            
+            (TXDELTA_TARGET, len(new), len(b"(s")),  # Copy "(s"
+            (TXDELTA_TARGET, len(b"(n"), len(b"ew)")),  # Copy "ew)"
+
             # Copy as target is generated
-            (TXDELTA_TARGET, len(new + source), len("(sew)") * 2),
+            (TXDELTA_TARGET, len(new + source), len(b"(sew)") * 2),
         )
-        result = "(new)(source)(sew)(sew)(sew)"
-        
+        result = b"(new)(source)(sew)(sew)(sew)"
+
         # (source offset, source length, result length, src_ops, ops, new)
         handler((0, len(source), len(result), 0, ops, new))
         handler(None)
@@ -69,12 +70,13 @@ class DeltaTests(TestCase):
 class MarshallTests(TestCase):
 
     def test_encode_length(self):
-        self.assertEqual("\x81\x02", encode_length(130))
+        self.assertEqual(bytearray(b"\x81\x02"), encode_length(130))
 
     def test_roundtrip_length(self):
-        self.assertEqual((42, ""), decode_length(encode_length(42)))
-
+        self.assertEqual((42, bytes()), decode_length(encode_length(42)))
 
     def test_roundtrip_window(self):
-        mywindow = (0, 0, 3, 1, [(2, 0, 3)], 'foo')
-        self.assertEqual([mywindow], list(unpack_svndiff0(pack_svndiff0([mywindow]))))
+        mywindow = (0, 0, 3, 1, [(2, 0, 3)], b'foo')
+        self.assertEqual(
+            [mywindow],
+            list(unpack_svndiff0(pack_svndiff0([mywindow]))))
