@@ -24,6 +24,7 @@ from subvertpy.marshall import (
     )
 from subvertpy.tests import TestCase
 
+
 class TestMarshalling(TestCase):
 
     def test_literal_txt(self):
@@ -41,55 +42,54 @@ class TestMarshalling(TestCase):
     def test_marshall_error(self):
         e = MarshallError("bla bla")
         self.assertEqual("bla bla", e.__str__())
-    
+
     def test_marshall_int(self):
-        self.assertEqual("1 ", marshall(1))
+        self.assertEqual(b"1 ", marshall(1))
 
     def test_marshall_list(self):
-        self.assertEqual("( 1 2 3 4 ) ", marshall([1,2,3,4]))
-    
+        self.assertEqual(b"( 1 2 3 4 ) ", marshall([1, 2, 3, 4]))
+
     def test_marshall_list_mixed(self):
-        self.assertEqual("( 1 3 4 3:str ) ", marshall([1,3,4,"str"]))
+        self.assertEqual(b"( 1 3 4 3:str ) ", marshall([1, 3, 4, "str"]))
 
     def test_marshall_literal(self):
-        self.assertEqual("foo ", marshall(literal("foo")))
+        self.assertEqual(b"foo ", marshall(literal("foo")))
 
     def test_marshall_string(self):
-        self.assertEqual("3:foo ", marshall("foo"))
+        self.assertEqual(b"3:foo ", marshall("foo"))
 
     def test_marshall_raises(self):
         self.assertRaises(MarshallError, marshall, dict())
 
     def test_marshall_list_nested(self):
-        self.assertEqual("( ( ( 3 ) 4 ) ) ", marshall([[[3], 4]]))
+        self.assertEqual(b"( ( ( 3 ) 4 ) ) ", marshall([[[3], 4]]))
 
     def test_marshall_string_space(self):
-        self.assertEqual("5:bla l ", marshall("bla l"))
+        self.assertEqual(b"5:bla l ", marshall("bla l"))
 
     def test_unmarshall_string(self):
-        self.assertEqual(('', "bla l"), unmarshall("5:bla l"))
+        self.assertEqual((b'', b"bla l"), unmarshall(b"5:bla l"))
 
     def test_unmarshall_list(self):
-        self.assertEqual(('', [4,5]), unmarshall("( 4 5 ) "))
+        self.assertEqual((b'', [4, 5]), unmarshall(b"( 4 5 ) "))
 
     def test_unmarshall_int(self):
-        self.assertEqual(('', 2), unmarshall("2 "))
+        self.assertEqual((b'', 2), unmarshall(b"2 "))
 
     def test_unmarshall_literal(self):
-        self.assertEqual(('', literal("x")), unmarshall("x "))
+        self.assertEqual((b'', literal("x")), unmarshall(b"x "))
 
     def test_unmarshall_empty(self):
-        self.assertRaises(MarshallError, unmarshall, "")
+        self.assertRaises(MarshallError, unmarshall, b"")
 
     def test_unmarshall_nospace(self):
-        self.assertRaises(MarshallError, unmarshall, "nospace")
+        self.assertRaises(MarshallError, unmarshall, b"nospace")
 
     def test_unmarshall_toolong(self):
-        self.assertRaises(MarshallError, unmarshall, "43432432:bla")
+        self.assertRaises(MarshallError, unmarshall, b"43432432:bla")
 
-    def test_unmarshall_literal(self):
-        self.assertRaises(MarshallError, unmarshall, ":-3213")
+    def test_unmarshall_literal_negative(self):
+        self.assertRaises(MarshallError, unmarshall, b":-3213")
 
     def test_unmarshall_open_list(self):
-        self.assertRaises(MarshallError, unmarshall, "( 3 4 ")
-
+        self.assertRaises(MarshallError, unmarshall, b"( 3 4 ")
